;* --------------------------------------------------------------------------------------
;*  Copyright (C) 2005 Maxim Integrated Products, Inc. All Rights Reserved.
;*
;*  Permission is hereby granted, free of charge, to any person obtaining a
;*  copy of this software and associated documentation files (the "Software"),
;*  to deal in the Software without restriction, including without limitation
;*  the rights to use, copy, modify, merge, publish, distribute, sublicense,
;*  and/or sell copies of the Software, and to permit persons to whom the
;*  Software is furnished to do so, subject to the following conditions:
;*
;*  The above copyright notice and this permission notice shall be included
;*  in all copies or substantial portions of the Software.
;*
;*  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
;*  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
;*  MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
;*  IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES
;*  OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
;*  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
;*  OTHER DEALINGS IN THE SOFTWARE.
;*
;*  Filename:      main.asm
;*  Description:   A program that uses the MAXQ2000 Evaluation Kit to communicate
;*                 with MAX6951 8-digit LED driver using SPI interface
;*  Date:          Dec 8, 2005
;*  Version:       0.10
;*  Author:		   Mulong_Gao@maximhq.com	 
;*
;*  To use this program, you must have a MAXQ2000 EVKit and a MAX6951 EVKit. 
;*  1. MAXQ2000 EVKit Jumper and DIP Switch Settings:
;*	   SW3 #1-#8: off
;*	   JU1:  connect Pins 1 and 2
;*	   JU2:  connect Pins 1 and 2
;*	   JU3:  connect Pins 1 and 2
;*	   JU4:  open
;*	   JU10: open
;*	   JU11: on (MAXQ2000 EVKit is powered by JTAG interface)
;*  2. MAX6951 Jumper Settings:
;*	   JU2, JU3, JU4: open   
;* --------------------------------------------------------------------------------------

$include (maxq2000_spi.inc)
$include (maxq2000ev_6951.inc)

ORG 0000H 

	call	max6951_init			; initialize MAXQ2000 SPI interface

main_demoloop:

	; display 0, 1, 2, 3, 4, 5, ..., F, 8. 
	; in hexadecimal decode mode
	move 	ACC, #01FFh				; restore to hexadecimal decode mode
	call	max6951_transmit

	call 	max6951_set_all_0		; display all 0
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_1		; display all 1
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_2		; display all 2
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_3		; display all 3
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_4		; display all 4
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_5		; display all 5
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_6		; display all 6
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_7		; display all 7
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_8		; display all 8
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_9		; display all 9
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_A		; display all A
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_B		; display all B
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_C		; display all C
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_D		; display all D
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_E		; display all E
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_set_all_F		; display all F
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	call 	max6951_light_all		; display all segments
	call 	max6951_e_d_s_d			; enable, delay, shutdown, delay

	; display 0-9, A,B,C,D,E,F,H,L,P,Q,Y 
	; it's also recognizable to display G,J,S, etc.	
	; in no-decode mode
	move	ACC, #0100h						; no-decode mode
	call	max6951_transmit

	call 	max6951_set_all_0_nodecode		; display all 0
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_1_nodecode		; display all 1
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_2_nodecode		; display all 2
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_3_nodecode		; display all 3
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_4_nodecode		; display all 4
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_5_nodecode		; display all 5
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_6_nodecode		; display all 6
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_7_nodecode				; display all 7
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_8_nodecode		; display all 8
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_9_nodecode		; display all 9
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_A_nodecode		; display all A
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_B_nodecode		; display all B
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay
		
	call 	max6951_set_all_C_nodecode		; display all C
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_D_nodecode		; display all D
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_E_nodecode		; display all E
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_F_nodecode		; display all F
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_H_nodecode		; display all H
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_L_nodecode		; display all L
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay	

	call 	max6951_set_all_P_nodecode		; display all P
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_Q_nodecode		; display all Q
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_set_all_Y_nodecode		; display all Y
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	call 	max6951_light_all_nodecode		; display all segments
	call 	max6951_e_d_s_d					; enable, delay, shutdown, delay

	; dimming loop
	call    max6951_enable
	move 	ACC, #0100h						; put the MAX6951 in no docode mode
	call	max6951_transmit						
	call	max6951_screenshot2				; display "XHELLOXX"

	move	ACC, #60
	move 	ACC, #020Fh	
	call 	max6951_transmit		; Set display intensity = 16/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #020Eh
	call 	max6951_transmit		; Set display intensity = 15/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #020Dh
	call 	max6951_transmit		; Set display intensity = 14/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #020Ch
	call 	max6951_transmit		; Set display intensity = 13/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #020Bh
	call 	max6951_transmit		; Set display intensity = 12/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #020Ah
	call 	max6951_transmit		; Set display intensity = 11/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #0209h
	call 	max6951_transmit		; Set display intensity = 10/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #0208h
	call 	max6951_transmit		; Set display intensity = 9/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #0207h
	call 	max6951_transmit		; Set display intensity = 8/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #0206h
	call 	max6951_transmit		; Set display intensity = 7/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #0205h
	call 	max6951_transmit		; Set display intensity = 6/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #0204h
	call 	max6951_transmit		; Set display intensity = 5/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #0203h
	call 	max6951_transmit		; Set display intensity = 4/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #0202h
	call 	max6951_transmit		; Set display intensity = 3/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #0201h
	call 	max6951_transmit		; Set display intensity = 2/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #0200h
	call 	max6951_transmit		; Set display intensity = 1/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second
	move 	ACC, #020Fh
	call 	max6951_transmit		; Set display intensity = 16/16
	call	max6951_one_second_delay; delay 1 second
	call	max6951_one_second_delay; delay 1 second

	; scan limit test, intensity should decrease when scan limit increases 
scan_limit_loop:
	call 	max6951_light_all_nodecode		; display all segments
	move 	ACC, #0300h				; scan limit = 0 
	call    max6951_transmit
	call 	max6951_half_second_delay

	move 	ACC, #0301h				; scan limit = 1 
	call    max6951_transmit
	call 	max6951_half_second_delay

	move 	ACC, #0302h				; scan limit = 2 
	call    max6951_transmit
	call 	max6951_half_second_delay

	move 	ACC, #0303h				; scan limit = 3 
	call    max6951_transmit
	call 	max6951_half_second_delay

	move 	ACC, #0304h				; scan limit = 4 
	call    max6951_transmit
	call 	max6951_half_second_delay

	move 	ACC, #0305h				; scan limit = 5 
	call    max6951_transmit
	call 	max6951_half_second_delay

	move 	ACC, #0306h				; scan limit = 6 
	call    max6951_transmit
	call 	max6951_half_second_delay

	move 	ACC, #0307h				; scan limit = 7 
	call    max6951_transmit
	call 	max6951_half_second_delay

	; blinking loop
	move 	ACC, #01FFh				; restore to hexadecimal decode mode
	call	max6951_transmit

blinking_loop:
	call	max6951_set_P0_0_7_P1_0 
	move 	ACC, #040Dh				; enable display, fast blink, global blink.
	call 	max6951_transmit
	call 	max6951_one_second_delay; blinking time = 5 seconds 
	call 	max6951_one_second_delay
	call 	max6951_one_second_delay
	call 	max6951_one_second_delay
	call 	max6951_one_second_delay

	; display and scroll "HELLO" from right to left 10 times
	call 	max6951_scroll_R_to_L
	
	; display and scroll "HELLO" from left to right 10 times
	call	max6951_scroll_L_to_R

	; display and bounce between the LED edeges
	call	max6951_bouncing

	; counting, from 0 - 99999999 
	call	max6951_counting

	JUMP 	main_demoloop
END

